==> blockr.core_0.1.0.tar.gz: blockr.core/tests/testthat/_snaps/board-class.md <==
# block constructor

    Code
      print(board)
    Output
      <board>
      
      Blocks[5]:
      
      d<merge_block<transform_block<block>>>
      Name: "Merge block"
      Data inputs: "x" and "y"
      Initial block state:
       $ by   : chr(0)
       $ all_x: logi FALSE
       $ all_y: logi FALSE
      Constructor: blockr.core::new_merge_block()
      
      a<dataset_block<data_block<block>>>
      Name: "Dataset block"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      c<subset_block<transform_block<block>>>
      Name: "Subset block"
      Data inputs: "data"
      Initial block state:
       $ subset: chr ""
       $ select: chr ""
      Constructor: blockr.core::new_subset_block()
      
      e<subset_block<transform_block<block>>>
      Name: "Subset block"
      Data inputs: "data"
      Initial block state:
       $ subset: chr ""
       $ select: chr ""
      Constructor: blockr.core::new_subset_block()
      
      b<dataset_block<data_block<block>>>
      Name: "Dataset block"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      Links[4]:
      
      ad: a -> d (x)
      cd: c -> d (y)
      bc: b -> c (data)
      de: d -> e (data)
      
      Stacks[1]:
      
      bc<stack[2]>
      Name: "Stack 1"
      Blocks: "b" and "c"
      
      Options:
       $ board_name : chr "Board"
       $ n_rows     : int 50
       $ page_size  : int 5
       $ filter_rows: logi FALSE
       $ dark_mode  : NULL

---

    Code
      print(rm_blocks(board, "c"))
    Output
      <board>
      
      Blocks[4]:
      
      d<merge_block<transform_block<block>>>
      Name: "Merge block"
      Data inputs: "x" and "y"
      Initial block state:
       $ by   : chr(0)
       $ all_x: logi FALSE
       $ all_y: logi FALSE
      Constructor: blockr.core::new_merge_block()
      
      a<dataset_block<data_block<block>>>
      Name: "Dataset block"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      e<subset_block<transform_block<block>>>
      Name: "Subset block"
      Data inputs: "data"
      Initial block state:
       $ subset: chr ""
       $ select: chr ""
      Constructor: blockr.core::new_subset_block()
      
      b<dataset_block<data_block<block>>>
      Name: "Dataset block"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      Links[2]:
      
      ad: a -> d (x)
      de: d -> e (data)
      
      Stacks[1]:
      
      bc<stack[1]>
      Name: "Stack 1"
      Blocks: "b"
      
      Options:
       $ board_name : chr "Board"
       $ n_rows     : int 50
       $ page_size  : int 5
       $ filter_rows: logi FALSE
       $ dark_mode  : NULL

==> blockr.core_0.1.1.tar.gz: blockr.core/tests/testthat/_snaps/board-class.md <==
# board constructor

    Code
      print(board)
    Output
      <board>
      
      Blocks[5]:
      
      d<merge_block<transform_block<block>>>
      Name: "Merge"
      Data inputs: "x" and "y"
      Initial block state:
       $ by   : chr(0)
       $ all_x: logi FALSE
       $ all_y: logi FALSE
      Constructor: blockr.core::new_merge_block()
      
      a<dataset_block<data_block<block>>>
      Name: "Dataset"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      c<subset_block<transform_block<block>>>
      Name: "Subset"
      Data inputs: "data"
      Initial block state:
       $ subset: chr ""
       $ select: chr ""
      Constructor: blockr.core::new_subset_block()
      
      e<subset_block<transform_block<block>>>
      Name: "Subset"
      Data inputs: "data"
      Initial block state:
       $ subset: chr ""
       $ select: chr ""
      Constructor: blockr.core::new_subset_block()
      
      b<dataset_block<data_block<block>>>
      Name: "Dataset"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      Links[4]:
      
      ad: a -> d (x)
      cd: c -> d (y)
      bc: b -> c (data)
      de: d -> e (data)
      
      Stacks[1]:
      
      bc<stack[2]>
      Name: "Stack"
      Blocks: "b" and "c"
      
      Options:
      <board_options[4]>
        board_name: NULL
        show_conditions: warning, error
        thematic: NULL
        dark_mode: NULL

---

    Code
      print(rm_blocks(board, "e"))
    Output
      <board>
      
      Blocks[4]:
      
      d<merge_block<transform_block<block>>>
      Name: "Merge"
      Data inputs: "x" and "y"
      Initial block state:
       $ by   : chr(0)
       $ all_x: logi FALSE
       $ all_y: logi FALSE
      Constructor: blockr.core::new_merge_block()
      
      a<dataset_block<data_block<block>>>
      Name: "Dataset"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      c<subset_block<transform_block<block>>>
      Name: "Subset"
      Data inputs: "data"
      Initial block state:
       $ subset: chr ""
       $ select: chr ""
      Constructor: blockr.core::new_subset_block()
      
      b<dataset_block<data_block<block>>>
      Name: "Dataset"
      No data inputs
      Initial block state:
       $ dataset: chr(0)
       $ package: chr "datasets"
      Constructor: blockr.core::new_dataset_block()
      
      Links[3]:
      
      ad: a -> d (x)
      cd: c -> d (y)
      bc: b -> c (data)
      
      Stacks[1]:
      
      bc<stack[2]>
      Name: "Stack"
      Blocks: "b" and "c"
      
      Options:
      <board_options[4]>
        board_name: NULL
        show_conditions: warning, error
        thematic: NULL
        dark_mode: NULL
